@@ -176,43 +176,44 @@ class ItemName:
     TRADING_ITEM_MAGNIFYING_GLASS = "Magnifying Glass"
     PIECE_OF_POWER = "Piece Of Power"
 
-trade_item_prog = ItemClassification.progression
+trade_item_prog = ItemClassification.progression_deprioritized
+progression_useful = ItemClassification.progression | ItemClassification.useful
 
 links_awakening_items = [
-    ItemData(ItemName.POWER_BRACELET, "POWER_BRACELET", ItemClassification.progression),
-    ItemData(ItemName.SHIELD, "SHIELD", ItemClassification.progression),
-    ItemData(ItemName.BOW, "BOW", ItemClassification.progression),
-    ItemData(ItemName.HOOKSHOT, "HOOKSHOT", ItemClassification.progression),
-    ItemData(ItemName.MAGIC_ROD, "MAGIC_ROD", ItemClassification.progression),
-    ItemData(ItemName.PEGASUS_BOOTS, "PEGASUS_BOOTS", ItemClassification.progression),
-    ItemData(ItemName.OCARINA, "OCARINA", ItemClassification.progression),
-    ItemData(ItemName.FEATHER, "FEATHER", ItemClassification.progression),
-    ItemData(ItemName.SHOVEL, "SHOVEL", ItemClassification.progression),
-    ItemData(ItemName.MAGIC_POWDER, "MAGIC_POWDER", ItemClassification.progression),
-    ItemData(ItemName.BOMB, "BOMB", ItemClassification.progression),
-    ItemData(ItemName.SWORD, "SWORD", ItemClassification.progression),
-    ItemData(ItemName.FLIPPERS, "FLIPPERS", ItemClassification.progression),
+    ItemData(ItemName.POWER_BRACELET, "POWER_BRACELET", progression_useful),
+    ItemData(ItemName.SHIELD, "SHIELD", progression_useful),
+    ItemData(ItemName.BOW, "BOW", progression_useful),
+    ItemData(ItemName.HOOKSHOT, "HOOKSHOT", progression_useful),
+    ItemData(ItemName.MAGIC_ROD, "MAGIC_ROD", progression_useful),
+    ItemData(ItemName.PEGASUS_BOOTS, "PEGASUS_BOOTS", progression_useful),
+    ItemData(ItemName.OCARINA, "OCARINA", progression_useful),
+    ItemData(ItemName.FEATHER, "FEATHER", progression_useful),
+    ItemData(ItemName.SHOVEL, "SHOVEL", progression_useful),
+    ItemData(ItemName.MAGIC_POWDER, "MAGIC_POWDER", progression_useful),
+    ItemData(ItemName.BOMB, "BOMB", progression_useful),
+    ItemData(ItemName.SWORD, "SWORD", progression_useful),
+    ItemData(ItemName.FLIPPERS, "FLIPPERS", progression_useful),
     ItemData(ItemName.MEDICINE, "MEDICINE", ItemClassification.useful),
     ItemData(ItemName.TAIL_KEY, "TAIL_KEY", ItemClassification.progression),
     ItemData(ItemName.ANGLER_KEY, "ANGLER_KEY", ItemClassification.progression),
     ItemData(ItemName.FACE_KEY, "FACE_KEY", ItemClassification.progression),
     ItemData(ItemName.BIRD_KEY, "BIRD_KEY", ItemClassification.progression),
     ItemData(ItemName.SLIME_KEY, "SLIME_KEY", ItemClassification.progression),
-    ItemData(ItemName.GOLD_LEAF, "GOLD_LEAF", ItemClassification.progression),
+    ItemData(ItemName.GOLD_LEAF, "GOLD_LEAF", ItemClassification.progression_deprioritized),
     ItemData(ItemName.RUPEES_20, "RUPEES_20", ItemClassification.progression_deprioritized_skip_balancing),
     ItemData(ItemName.RUPEES_50, "RUPEES_50", ItemClassification.progression_deprioritized_skip_balancing),
     ItemData(ItemName.RUPEES_100, "RUPEES_100", ItemClassification.progression_deprioritized_skip_balancing),
-    ItemData(ItemName.RUPEES_200, "RUPEES_200", ItemClassification.progression_deprioritized_skip_balancing),
-    ItemData(ItemName.RUPEES_500, "RUPEES_500", ItemClassification.progression_deprioritized_skip_balancing),
-    ItemData(ItemName.SEASHELL, "SEASHELL", ItemClassification.progression_deprioritized_skip_balancing),
+    ItemData(ItemName.RUPEES_200, "RUPEES_200", ItemClassification.progression),
+    ItemData(ItemName.RUPEES_500, "RUPEES_500", ItemClassification.progression),
+    ItemData(ItemName.SEASHELL, "SEASHELL", ItemClassification.progression_skip_balancing),
     ItemData(ItemName.MESSAGE, "MESSAGE", ItemClassification.filler),
     ItemData(ItemName.GEL, "GEL", ItemClassification.trap),
-    ItemData(ItemName.BOOMERANG, "BOOMERANG", ItemClassification.progression),
+    ItemData(ItemName.BOOMERANG, "BOOMERANG", progression_useful),
     ItemData(ItemName.HEART_PIECE, "HEART_PIECE", ItemClassification.filler),
     ItemData(ItemName.BOWWOW, "BOWWOW", ItemClassification.progression),
     ItemData(ItemName.ARROWS_10, "ARROWS_10", ItemClassification.filler),
     ItemData(ItemName.SINGLE_ARROW, "SINGLE_ARROW", ItemClassification.filler),
-    ItemData(ItemName.ROOSTER, "ROOSTER", ItemClassification.progression),
+    ItemData(ItemName.ROOSTER, "ROOSTER", progression_useful),
     ItemData(ItemName.MAX_POWDER_UPGRADE, "MAX_POWDER_UPGRADE", ItemClassification.filler),
     ItemData(ItemName.MAX_BOMBS_UPGRADE, "MAX_BOMBS_UPGRADE", ItemClassification.filler),
     ItemData(ItemName.MAX_ARROWS_UPGRADE, "MAX_ARROWS_UPGRADE", ItemClassification.filler),
@@ -220,8 +221,8 @@ links_awakening_items = [
     ItemData(ItemName.BLUE_TUNIC, "BLUE_TUNIC", ItemClassification.useful),
     ItemData(ItemName.HEART_CONTAINER, "HEART_CONTAINER", ItemClassification.useful),
     #ItemData(ItemName.BAD_HEART_CONTAINER, "BAD_HEART_CONTAINER", ItemClassification.trap),
-    ItemData(ItemName.TOADSTOOL, "TOADSTOOL", ItemClassification.progression),
     ItemData(ItemName.GUARDIAN_ACORN, "GUARDIAN_ACORN", ItemClassification.filler),
+    ItemData(ItemName.TOADSTOOL, "TOADSTOOL", progression_useful),
     DungeonItemData(ItemName.KEY, "KEY", ItemClassification.progression),
     DungeonItemData(ItemName.KEY1, "KEY1", ItemClassification.progression),
     DungeonItemData(ItemName.KEY2, "KEY2", ItemClassification.progression),
@@ -262,16 +263,16 @@ links_awakening_items = [
     DungeonItemData(ItemName.COMPASS7, "COMPASS7", ItemClassification.filler),
     DungeonItemData(ItemName.COMPASS8, "COMPASS8", ItemClassification.filler),
     DungeonItemData(ItemName.COMPASS9, "COMPASS9", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK, "STONE_BEAK", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK1, "STONE_BEAK1", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK2, "STONE_BEAK2", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK3, "STONE_BEAK3", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK4, "STONE_BEAK4", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK5, "STONE_BEAK5", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK6, "STONE_BEAK6", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK7, "STONE_BEAK7", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK8, "STONE_BEAK8", ItemClassification.filler),
-    DungeonItemData(ItemName.STONE_BEAK9, "STONE_BEAK9", ItemClassification.filler),
+    DungeonItemData(ItemName.STONE_BEAK, "STONE_BEAK", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK1, "STONE_BEAK1", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK2, "STONE_BEAK2", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK3, "STONE_BEAK3", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK4, "STONE_BEAK4", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK5, "STONE_BEAK5", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK6, "STONE_BEAK6", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK7, "STONE_BEAK7", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK8, "STONE_BEAK8", ItemClassification.useful),
+    DungeonItemData(ItemName.STONE_BEAK9, "STONE_BEAK9", ItemClassification.useful),
     ItemData(ItemName.SONG1, "SONG1", ItemClassification.progression),
     ItemData(ItemName.SONG2, "SONG2", ItemClassification.useful),
     ItemData(ItemName.SONG3, "SONG3", ItemClassification.progression),
@@ -418,6 +419,25 @@ links_awakening_item_name_groups: typing.Dict[str, typing.Set[str]] = {
         "Red Tunic",
         "Blue Tunic",
     },
+    "Equipment": {
+        "Bomb",
+        "Boomerang",
+        "Bow",
+        "BowWow",
+        "Feather",
+        "Flippers",
+        "Hookshot",
+        "Magic Powder",
+        "Magic Rod",
+        "Ocarina",
+        "Pegasus Boots",
+        "Progressive Power Bracelet",
+        "Progressive Shield",
+        "Progressive Sword",
+        "Rooster",
+        "Shovel",
+        "Toadstool",
+    },
     "Bush Breakers": {
         "Progressive Power Bracelet",
         "Magic Rod",
